==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_service_get_quartiles_response_200_quartiles_item_odti.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetQuartilesResponse_200QuartilesItemODTI")


@attr.s(auto_attribs=True)
class PoolService_GetQuartilesResponse_200QuartilesItemODTI:
    """ Debt-To-Income at origination. """

    average: Union[Unset, float] = UNSET
    first: Union[Unset, float] = UNSET
    maximum: Union[Unset, float] = UNSET
    minimum: Union[Unset, float] = UNSET
    second: Union[Unset, float] = UNSET
    third: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        average = self.average
        first = self.first
        maximum = self.maximum
        minimum = self.minimum
        second = self.second
        third = self.third

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if average is not UNSET:
            field_dict["average"] = average
        if first is not UNSET:
            field_dict["first"] = first
        if maximum is not UNSET:
            field_dict["maximum"] = maximum
        if minimum is not UNSET:
            field_dict["minimum"] = minimum
        if second is not UNSET:
            field_dict["second"] = second
        if third is not UNSET:
            field_dict["third"] = third

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        average = d.pop("average", UNSET)

        first = d.pop("first", UNSET)

        maximum = d.pop("maximum", UNSET)

        minimum = d.pop("minimum", UNSET)

        second = d.pop("second", UNSET)

        third = d.pop("third", UNSET)

        pool_service_get_quartiles_response_200_quartiles_item_odti = cls(
            average=average,
            first=first,
            maximum=maximum,
            minimum=minimum,
            second=second,
            third=third,
        )

        pool_service_get_quartiles_response_200_quartiles_item_odti.additional_properties = (
            d
        )
        return pool_service_get_quartiles_response_200_quartiles_item_odti

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_service_get_quartiles_response_200_quartiles_item_odti.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetQuartilesResponse_200QuartilesItemOdti")


@attr.s(auto_attribs=True)
class PoolService_GetQuartilesResponse_200QuartilesItemOdti:
    """ Original Debt-To-Income at issuance. """

    average: Union[Unset, float] = UNSET
    first: Union[Unset, float] = UNSET
    maximum: Union[Unset, float] = UNSET
    minimum: Union[Unset, float] = UNSET
    second: Union[Unset, float] = UNSET
    third: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        average = self.average
        first = self.first
        maximum = self.maximum
        minimum = self.minimum
        second = self.second
        third = self.third

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if average is not UNSET:
            field_dict["average"] = average
        if first is not UNSET:
            field_dict["first"] = first
        if maximum is not UNSET:
            field_dict["maximum"] = maximum
        if minimum is not UNSET:
            field_dict["minimum"] = minimum
        if second is not UNSET:
            field_dict["second"] = second
        if third is not UNSET:
            field_dict["third"] = third

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        average = d.pop("average", UNSET)

        first = d.pop("first", UNSET)

        maximum = d.pop("maximum", UNSET)

        minimum = d.pop("minimum", UNSET)

        second = d.pop("second", UNSET)

        third = d.pop("third", UNSET)

        pool_service_get_quartiles_response_200_quartiles_item_odti = cls(
            average=average,
            first=first,
            maximum=maximum,
            minimum=minimum,
            second=second,
            third=third,
        )

        pool_service_get_quartiles_response_200_quartiles_item_odti.additional_properties = (
            d
        )
        return pool_service_get_quartiles_response_200_quartiles_item_odti

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
